<?php

/*
 * Add functions here for every participant content type that requires
 * additional processing. Name the functions after the operations
 * available to nodeapi, as connect_CONTENT_TYPE_OPERATION (eg,
 * 'connect_testparticipant_validate').
 *
 * 'Additional processing' consists of anything above and beyond just
 * being added to the database (and so linked to the parent node. This
 * might include being added to civicrm, registered as a drupal user,
 * triggering an email event, etc.
 *
 * Put uniqueness tests in validate, and post-processing in insert.
 * (Don't try to use 'submit' because the node_save() function used in
 * the module skips it.)
 *
 * Various validation and processing functions are defined at the
 * bottom of connect.module
 *
 * The validations functions are called to validate the form data.
 *
 * The insert functions are called when the CCK data is inserted.
 *
 */

/*
 *  participant_basic -- no special action
 */
function connect_participant_basic_validate($parent, $form_values) {
  /* Validity check: one person, one vote */
  return connect_validate_unique_email($parent, $form_values);
}


/*
 * participant_email -- sends an email to a target
 */
function connect_participant_email_validate($parent, $form_values) {
  /* Validity check: one person, one vote */
  return connect_validate_unique_email($node);
}

function connect_participant_email_insert(&$node) {
  $petition_nid = $node->field_parent_id[0]['value'];
  $petition_obj = node_load($petition_nid);

  /* Mail Action */
  return connect_action_email($petition_obj, $node);
}

/*
 *   OCSJ
 *
 * 		- adds target to civicrm
 * 		- manages data entry form ( true if $user = member of OCSJ group)
 */
function connect_ocsj_data_validate($parent, $form_values) {
	return true;
  /* Validity check: one person, one vote */
  return connect_validate_unique_email($parent, $form_values);
}

function connect_ocsj_data_insert(&$node) {
  $petition_nid = $node->field_parent_id[0]['value'];
  $petition_obj = node_load($petition_nid);

  /* Make this form available for data entry use */
  connect_action_data_entry_og($petition_obj, $node);

  /* look up and insert ON electoral riding */
	connect_action_insert_riding($node, 'provincial', 'ontario');

  /* Add to CiviCRM */
  connect_action_civicrm_insert($petition_obj, $node);
}
?>
